Localization.define('ro_RO') do |l|
  l.store "your blog", "blog-ul tău"
  l.store "Typo admin", "Administrare Typo"
  l.store "Publish", "Publică"
  l.store "Manage", "Articole"
  l.store "Discuss", "Discuții"
  l.store "Design", "Design"
  l.store "%d Users", ["Utilizator", "%d Utilizatori"]
  l.store "Settings", "Configurare"
  l.store "Things you can do", "Acțiuni"
  l.store "with %s Famfamfam iconset %s", "cu %s pictograme Famfamfam %s"
  
  #admin/login.rhtml
  l.store "Username", "Utilizator"
  l.store "Password", "Parola"
  l.store "Login", "Login"
  l.store "Back to the blog", "Înapoi la blog"

  # admin/logout.rhtml
  l.store "You are now logged out of the system", "Ați ieșit din aplicație"
  l.store "Do you want to go to your blog?", "Doriți să vizitați pagina principală a blogului?"
  l.store "Logoff", "Ieșire"
  
  # admin/signup.rhtml
  l.store "Signup", "Înregistrare"
  l.store "Desired login", "Nume de utilizator"
  l.store "Display name", "Numele real"
  l.store "Email", "Email"
  l.store "Choose password", "Parola"
  l.store "Confirm password", "Confirmați parola"
  
  #admin/base/recent_comments.rhtml
  l.store "Recent comments", "Comentarii recente"

  #admin/base/recent_trackbacks.rhtml
  l.store "Recent trackbacks", "Retrolegături recente"
  
  #admin/blacklist/_blacklis_patterns.rhtml
  l.store "Pattern", "Model"
  l.store "Type", "Tip"
  l.store "Edit", "Editare"
  l.store "Delete", "Ștergere"
  
  #admin/blacklist/_form.rhtml
  l.store "String", "Șir de caractere"
  l.store "Regex", "Expresie regulată"
  
  #admin/blacklist/_quick_post.rhtml
  l.store "Add pattern", "Adăugare model"
  l.store "Cancel", "Anulare"
  l.store "or", "sau"
  
  #admin/blacklist/destroy.rhtml
  l.store "Blacklist Patterns", "Lista neagră"
  l.store "Show this pattern", "Afișează acest model"
  l.store "Are you sure you want to delete this item?", "Ești sigur că dorești să ștergi acest element?"
  
  #admin/blacklist/edit.rhtml
  l.store "Editing pattern", "Editarea modelului"
  
  #admin/blacklist/list.rhtml
  l.store "Create new Blacklist", "Crearea unei noi liste negre"
  
  #admin/cache/list.rhtml
  l.store "Cache", "Cache"
  
  #admin/categories/_categories.rhtml
  l.store "Category title", "Numele categoriei"
  l.store "%d Articles", ["Articol", "%d Articole"]
  
  #admin/categories/_form.rhtml
  l.store "Name", "Nume"
  
  #admin/categories/_quick_post.rhtml
  l.store "Title", "Titlu"
  l.store "Add category", "Adaugă o categorie"
  
  #admin/categorie/destroy.rhtml
  l.store "%d Categories", ["Categorie", "%d Categorii"]
  l.store "Show this category", "Afișează această categorie"
  l.store "Delete this category", "Șterge această categorie"
  l.store "Are you sure you want to delete the category ", "Ești sigur că dorești să ștergi această categorie"
  
  #admin/category/edit.rhtml
  l.store "Editing category", "Editarea categoriei" 
  
  #admin/category/list.rhtml
  l.store "Manage Categories", "Listează categoriile"
  l.store "Create new category", "Creează o categorie nouă"
  l.store "Reorder", "Ordonează"
  l.store "Sort alphabetically", "Ordonează alfabetic"
  l.store "Manage Articles", "Listează articolele"
  l.store "Manage Pages", "Listează paginile"
  l.store "Manage Resources", "Listează resursele"
  
  #admin/category/reorder.rhtml
  l.store "(Done)", "(Gata)"
  
  #admin/category/show
  l.store "Edit this category", "Editează această categorie"
  l.store "Articles in", "Articole în"

  #admin/comments/_form.rhtml
  l.store "Author", "Autor"
  l.store "Url", "Adresa"
  l.store "Body", "Conținut" 
  
  #admin/comments/comments.rhtml
  l.store "on", "la"

  #admin/comments/destroy.rhtml
  l.store "Comments for", "Comentariile la"
  
  #admin/comments/edit.rhtml
  l.store "Show this comment", "Arată acest comentariu"
  l.store "View comment on your blog", "Arată acest comentariu în blog"
  l.store "Editing comment", "Editarea unui comentariu"
  
  #admin/comments/list.rhtml
  l.store "IP", "Adresa IP"
  l.store "Posted date", "Publicat la"
  
  #admin/comments/new.rhtml
  l.store "Creating comment", "Creează un comentariu"
  
  #admin/content/_articles.rhtml
  l.store "Post title", "Titlul articolului"
  l.store "Posted at", "Data publicării"
  l.store "%d Comments", ["Comentariu", "%d Comentarii"]
  l.store "%d Trackbacks", ["Retrolegătură", "%d Retrolegături"]
  l.store "Status", "Status"
  l.store "Offline", "Offline"
  l.store "Online", "Online"
  l.store "no trackbacks", "fără retrolegături"
  l.store "no comments", "fără comentarii"
  #admin/content/_attachment.rhtml
  l.store "Remove", "Șterge"
  l.store "Really delete attachment", "Ești sigur că dorești să ștergi atașamentul"
  l.store "Add Another Attachment", "Adaugă un nou atașament"
  
  #admin/content/_form.rhtml
  l.store "Article Body", "Corpul articolului"
  l.store "Article Content", "Conținutul articolului"
  l.store "Extended Content", "Conținutul extins"
  l.store "%d Tags", ["Cuvînt cheie", "%d Cuvinte cheie"]
  l.store "Save", "Salvează"
  l.store "Article Attachments", "Atașamentele articolului"
  l.store "Article Options", "Opțiunile articolului"
  l.store "Permalink", "Legătură permanentă"
  l.store "Allow comments", "Se permit comentarii"
  l.store "Allow trackbacks", "Se permit retrolegături"
  l.store "Published", "Publicat"
  l.store "Publish at", "Publică la"
  l.store "Textfilter", "Filtru de text"
  
  #admin/content/_pages.rhtml
  l.store "Previous page", "Pagina anterioară"
  l.store "Next page", "Pagina următoare"
  
  #admin/content/_show_categories.rhtml
  l.store "Currently this article is listed in following categories", "Acest articol aparține următoarelor categorii"
  l.store "You can add it to the following categories", "Îl puteți adăuga următoarelor categorii"
  
  #admin/content/_show_ressources.rhtml
  l.store "Currently this article has the following resources", "Resursele disponibile acestui articol sînt"
  l.store "You can associate the following resources", "Puteți asocia următoarele resurse"
  
  #admin/content/destroy.rhtml
  l.store "Show this article", "Arată acest articol"
  l.store "Are you sure you want to delete this article", "Ești sigur că dorești ștergerea acestui articol"
  l.store "Delete this article", "Șterge acest articol"
  
  #admin/content/edit.rhtml
  l.store "Edit Article", "Editarea unui articol"
  l.store "View article on your blog", "Arată acest articol in blog"

  #admin/content/new.rhtml
  l.store "Write a Page", "Compune o pagină"
  l.store "Write an Article", "Scrie un articol"
  
  #admin/content/preview.rhtml
  l.store "Posted by", "Publicat de"
  
  #admin/content/show.rhtml
  l.store "Preview Article", "Previzualizarea unui articol"
  l.store "Edit this article", "Editează acest articol"
  l.store "Last updated", "Ultima modificare"
  l.store "Attachments", "Atașamente"
  
  #admin/feedback/list.rhtml
  l.store "Limit to spam", "Doar spam"
  l.store "Limit to unconfirmed", "Doar neconfirmate"
  l.store "Limit to unconfirmed spam", "Doar spam neconfirmat"
  l.store "Blacklist", "Lista neagră"
  l.store "Feedback Search", "Caută prin comentarii"
  l.store "Comments and Trackbacks for", "Comentarii și retrolegături pentru"
  
  #admin/general/index.rhtml
  l.store "Blog settings", "Setările blogului"
  l.store "Which settings group would you like to edit", "Ce grup de setări dorești să modifici"
  l.store "General settings", "Setări generale"
  l.store "General Settings", "Setări generale"
  l.store "Read", "Afișare"
  l.store "Write", "Publicare"
  l.store "Discuss", "Discuții"
  l.store "Notification", "Notificări"
  l.store "Spam Protection", "Protecție anti-spam"
  l.store "Resource Settings", "Setări ale resurselor"
  l.store "Cache", "Cache"
  l.store "Blog name", "Numele blogului"
  l.store "Blog subtitle", "Subtitlul blogului"
  l.store "Language", "Language" #Need translate
  l.store "This option let you choose between the simple admin interface or the complete one, displaying much more options and therefore more complicated to use. For advanced users only!","This option let you choose between the simple admin interface or the complete one, displaying much more options and therefore more complicated to use. For advanced users only!" #Need translate
  l.store "Blog URL", "Adresa blogului"
  l.store "Latitude, Longitude", "Latitudine, longitudine"
  l.store "Display", "Afișează"
  l.store "your lattitude and longitude", "latitudinea și longitudinea ta"
  l.store "exemple", "de pildă"
  l.store "Show blog name", "Afișează numele blogului"
  l.store "At the beginning of page title", "Înaintea titlului paginii"
  l.store "At the end of page title", "După titlul paginii"
  l.store "Don't show blog name in page title", "Nu afișa numele blogului în titlul paginii"
  l.store "Save Settings", "Salvează setările"
  l.store "articles on my homepage by default", "articole implicit în pagina principală"
  l.store "articles in my news feed by default", "articole implicit în RSS"
  l.store "Show full article on feed", "Include articole complete în RSS"
  l.store "Article filter", "Filtru pentru articole"
  l.store "Comments filter", "Filtru pentru comentarii"
  l.store "When publishing articles, Typo can send trackbacks to websites that you link to. This should be disabled for private blogs as it will leak non-public information to sites that you're discussing. For public blogs, there's no real point in disabling this.", "Cînd publici un articol, Typo poate trimite automat retrolegături site-urilor pe care le specifici. În cazul unui blog personal, această opțiune ar trebui dezactivată, ca să nu deconspire informații private. Dacă blogul e public, opțiunea aceasta poate rămîne activă."
  l.store "Send trackbacks", "Trimite retrolegături"
  l.store "URLs to ping automatically", "Site-uri de anunțat automat"
  l.store "This setting allows you to disable trackbacks for every article in your blog.  It won't remove existing trackbacks, but it will prevent any further attempt to add a trackback anywhere on your blog.", "Această opțiune va dezactiva trimiterea de retrolegături de acum înainte. Retrolegăturile existente vor rămîne în site-uri, dar alte retrolegături nu vor mai fi posibile nicăieri in blog."
  l.store "Disable trackbacks site-wide" ,"Dezactivează retrolegăturile în tot blogul"
  l.store "Enable Trackbacks by default", "Implicit retrolegăturile să fie active"
  l.store "You can enable site wide feedback moderation. If you do so, no comment or trackback will appear on your blog unless you validate it", 
          "Poți activa, pentru tot blogul, moderarea comentariilor. Dacă alegi să faci asta, niciun comentariu sau retrolegătură nu va apărea pe blog înainte de a fi validat(ă)"
  l.store "Enable feedback moderation", "Activează moderarea comentariilor"
  l.store "Enable comments by default", "Implicit comentariile să fie active"
  l.store "Show your email address", "Arată adresa ta de email"
  l.store "Enable gravatars", "Activează gravataruri"
  l.store "You can optionally disable non-Ajax comments. Typo will always use Ajax for comment submission if Javascript is enabled, so non-Ajax comments are either from spammers or users without Javascript.", "Opțional, puteți dezactiva comentariile non-AJAX. Typo va folosi întotdeauna AJAX pentru trimiterea comentariilor dacă funcționează Javascript la utilizator, astfel că orice comentariu care nu vine prin AJAX trebuie să vină fie de la spammeri, fie de la vizitatori fără Javascript."
  l.store "Allow non-ajax comments", "Permite comentarii non-AJAX"
  l.store "Disable comments after", "Dezactivează comentariile după "
  l.store "Set to 0 to never disable comments", "Comentariile nu vor fi dezactivate niciodată dacă alegi valoarea 0"
  l.store "Typo will automatically reject comments and trackbacks which contain over a certain amount of links in them", "Typo va respinge automat comentarii și retrolegături care conțin mai mult decît un anumit număr de legături"
  l.store "Max Links", "Număr maxim de legături"
  l.store "Set to 0 to never reject comments", "Comentariile nu vor fi respinse niciodată dacă alegi valoarea 0"
  l.store "Typo can notify you when new articles or comments are posted", "Typo te poate alerta la publicarea de noi articole sau comentarii"
  l.store "Source Email", "Expeditor email"
  l.store "Email address used by Typo to send notifications", "Adresa email folosită de Typo pentru a trimite alerte prin email"
  l.store "Jabber account", "Cont Jabber"
  l.store "Jabber account to use when sending Jabber notifications", "Contul de Jabber folosit pentru a trimite alerte prin Jabber"
  l.store "Jabber password", "Parola Jabber"
  l.store "Spam protection", "Protecție anti-spam"
  l.store "Enabling spam protection will make typo compare the IP address of posters as well as the contents of their posts against local and remote blacklists. Good defense against spam bots", "La activarea protecției anti-spam, Typo va compara adresa IP a utilizatorului care publică un articol, cît și conținutul articolului publicat, cu niște liste negre locale sau din altă parte. Reprezintă o bună apărare împotriva unui spam bot "
  l.store "Enable spam protection", "Activează protecția anti-spam"
  l.store "Typo can (optionally) use the %s spam-filtering service.  You need to register with Akismet and receive an API key before you can use their service.  If you have an Akismet key, enter it here", "Opțional, Typo poate folosi serviciul %s de filtrare spam. Trebuie să te înregistrezi la Akismet și să primești o cheie API pentru a putea folosi acest serviciu. Dacă ai deja o cheie Akismet, introdu-o aici"
  l.store "Akismet Key", "Cheia Akismet"
  l.store "The below settings act as defaults when you choose to publish an enclosure with iTunes metadata", "Setările de mai jos vor reprezenta valorile implicite atunci cînd vei publica un enclosure cu metainformații pentru iTunes"
  l.store "Subtitle", "Subtitlu"
  l.store "Summary", "Rezumat"
  l.store "Setting for channel", "Setări de canal"
  l.store "Optional Name", "Nume opțional"
  l.store "Not published by Apple", "Nepublicat de Apple"
  l.store "Copyright Information", "Drepturi"
  l.store "Explicit", "Conținut explicit"
  l.store "Empty Fragment Cache", "Golește cache"
  l.store "Rebuild cached HTML", "Reconstruiește paginile din cache"
  l.store "days", "zile"
  
  #admin/general/update_database
  l.store "Database migration", "Actualizări ale bazei de date"
  l.store "Information", "Informații"
  l.store "Current database version", "Versiunea curentă a bazei de date"
  l.store "New database version", "Versiunea nouă a bazei de date"
  l.store "Your database supports migrations", "Baza de date poate fi actualizată"
  l.store "yes", "da"
  l.store "no", "nu"
  l.store "Needed migrations", "Actualizări necesare"
  l.store "You are up to date!", "Baza de date este la zi!"
  l.store "Update database now", "Actualizează baza de date acum"
  l.store "may take a moment", "ar putea să dureze puțin"
  
  #admin/pages/_form.rhtml
  l.store "Page Body", "Conținutul paginii"
  l.store "Location", "Adresa"
  l.store "Page Options", "Opțiuni ale paginii"
  
  #admin/pages/_pages.rhtml
  l.store "Action", "Acțiuni"
  l.store "Pages","Pagini"
  l.store "Show this page", "Arată această pagină"
  l.store "Are you sure you want to delete the page", "Ești sigur că dorești să ștergi această pagină"
  l.store "Delete this page", "Șterge această pagină"
  
  #admin/pages/edit.rhtml
  l.store "Create new page", "Creează o pagină nouă"
  l.store "View page on your blog", "Arată această pagină în blog"
  l.store "Editing page", "Editarea paginii"
  l.store "Manage Text Filters", "Configurează filtrele de text"
  
  #admin/pages/show.rhtml
  l.store "Edit this page", "Editează această pagină"
  l.store "by", "de"
  
  #admin/ressources/_metadata_add.rhtml
  l.store "Resource MetaData", "Metainformații ale resursei"
  l.store "Set iTunes metadata for this enclosure", "Setează metainformații iTunes"
  l.store "Duration", "Durată"
  l.store "Key Words", "Cuvinte cheie"
  l.store "seperate with spaces", "separate de spațiu"
  
  #admin/resources/_metadata_edit.rhtml
  l.store "Remove iTunes Metadata", "Șterge metainformațiile iTunes"
  l.store "Content Type", "Tip de conținut (content type)"
  
  #admin/resources/_resources.rhtml
  l.store "Filename", "Nume de fișier"
  l.store "MetaData", "Metainformații"
  l.store "File Size", "Dimensiunea fișierului"
  l.store "Uploaded", "Încărcat la"
  l.store "Edit MetaData", "Editează metainformații"
  l.store "Add MetaData", "Adaugă metainformații"

  #admin/resources/destroy.rhtml
  l.store "File Uploads", "Încărcări de fișiere"
  l.store "Upload a new File", "Încarcă un fișier nou"
  l.store "Are you sure you want to delete this file", "Ești sigur că dorești să ștergi acest fișier"
  l.store "Delete this file from the webserver?", "Ștergi acest fișier de pe server?"

  #admin/resources/new.rhtml
  l.store "Upload a File to your Site", "Încarcă un fișier în site"
  l.store "Upload", "Încarcă"
  l.store "Upload a new Resource", "Încarcă o nouă resursă"
  
  #admin/sidebar/_avaliables.rhtml
  l.store "You have no plugins installed", "Niciun plugin instalat"
  
  #admin/sidebar/_publish.rhtml
  l.store "Changes published", "Schimbările au fost publicate"
  
  #admin/sidebar/_target.rhtml
  l.store "Drag some plugins here to fill your sidebar", "Trage plugin-uri aici pentru a popula bara laterală"
  
  #admin/sidebar/index.rhtml
  l.store "Choose a theme", "Alege o temă"
  l.store "Drag and drop to change the sidebar items displayed on this blog.  To remove items from the sidebar just click remove  Changes are saved immediately, but not activated until you click the 'Publish' button", "Trage și lasă obiecte pe bara laterală pentru a o modifica în blog. Pentru a șterge obiecte din bara laterală, apasă pe 'șterge'. Modificările se salvează imediat, dar nu vor fi activate pînă cînd apeși butonul 'publică'"
  l.store "Publish changes", "Publică modificările"
  l.store "Available Items", "Obiecte disponibile"
  l.store "Active Sidebar items", "Obiecte utilizate"

  #admin/textfilters/_form.rhtml
  l.store "Description", "Descriere"
  l.store "Markup type", "Tip de marcaj"
  l.store "Post-processing filters", "Filtre de post-procesare"
  l.store "Parameters", "Parametri"
  
  #admin/textfilters/_macros.rhtml
  l.store "Show Help", "Ajutor"
  
  #admin/textfilters/_textfilters.rhtml
  l.store "Markup", "Marcaj"
  l.store "Filters", "Filtre"
  
  #admin/textfilters/destroy.rhtml
  l.store "Text Filters", "Filtre de text"
  l.store "Are you sure you want to delete this filter", "Ești sigur că dorești să ștergi acest filtru"
  l.store "Delete this filter", "Șterge acest filtru"
  
  #admin/textfilters/edit.rhtml
  l.store "Editing textfilter", "Editarea unui filtru"
  
  #admin/textfilters/list.rhtml
  l.store "Create new text filter", "Creează un nou filtru de text"
  l.store "Customize Sidebar", "Personalizează bara laterală"
  l.store "Macros", "Macro-uri"
  
  #admin/textfilters/macro_help.rhtml
  l.store "Macro Filter Help", "Ajutor la filtrele macro"
  l.store "Creating text filter", "Crearea unui nou filtru de text"
  
  #admin/textfilters/show.rhtml
  l.store "Text Filter Details", "Detaliile filtrului de text"
  l.store "Edit this filter", "Editeaza acest filtru"
  l.store "See help text for this filter", "Ajutor la acest filtru"
  
  #admin/themes/index.rhtml
  l.store "Choose a theme", "Alege o temă"
  l.store "Activate", "Activează"
  l.store "Active theme", "Tema activă"
  
  #admin/trackbacks/edit.rhtml
  l.store "Trackbacks for", "Retrolegături pentru"
  l.store "Editing trackback", "Editarea retrolegăturii"
  
  #admin/trackbacks/new.rhtml
  l.store "Creating trackback", "Crearea unei retrolegături"
  l.store "Edit this trackback", "Editează această retrolegătură"
  
  #admin/users/_form.rhtml
  l.store 'Display Name', 'Nume real'
  l.store "Jabber", "Jabber"
  l.store "Password Confirmation", "Confirmă parola"
  l.store "Password confirmation", "Confirmă parola"
  l.store "Send notification messages via email", "Alerte prin email"
  l.store "Send notification messages when new articles are posted", "Alerte la publicarea de articole noi"
  l.store "Send notification messages when comments are posted", "Alerte la publicarea de comentarii noi"
  l.store 'this will be shown publicly if supplied', 'va fi vizibilă public'
  l.store 'this can be blank', 'nu este obligatoriu'
  l.store 'Anti-bot protection: How much is', 'Protecție anti-bot: cît fac'
  
  #admin/user/_user.rhtml
  l.store "Number of Articles", "Număr de articole"
  l.store "Number of Comments", "Număr de comentarii"
  l.store "Notified", "Alertă trimisă"
  l.store "via email", "prin email"
  
  #admin/user/destroy.rhtml
  l.store "Show this user", "Arată acest utilizator"
  l.store "Really delete user", "Ești sigur că dorești să ștergi acest utilizator"
  
  #admin/user/edit.rhtml
  l.store "Edit User", "Editează un utilizator"
  l.store "Editing User", "Editarea unui utilizator"
  l.store "New User", "Utilizator nou"
  l.store "Add new user", "Adaugă un utilizator nou"
  
  #admin/user/new.rhtml
  l.store "Creating user", "Crearea unui nou utilizator"
  
  #admin/user/show.rhtml
  l.store "User's articles", "Articole publicate de acest utilizator"
  l.store "Notify via email", "Primește alerte prin email"
  l.store "Notify on new articles", "Primește alerte la publicarea de articole noi"
  l.store "Notify on new comments", "Primește alerte la publicarea de comentarii noi"
  
  #articles/_comment.rhtml
  l.store "said", "a scris"
  l.store "This comment has been flagged for moderator approval.  It won't appear on this blog until the author approves it", "Acest comentariu a fost marcat pentru moderare. El nu va apărea în blog înainte de a fi aprobat."
  l.store 'later', 'mai tîrziu'
  
  #articles/_comment_box.rhtml
  l.store "Your name", "Nume"
  l.store "Your blog", "Site"
  l.store "Your email", "Email"
  l.store "Your message", "Comentariu"
  l.store "Comment Markup Help", "Ajutor la marcare"
  l.store "Preview comment", "Previzualizare"
  
  #articles/_trackback.rhtml
  l.store "From", "De la"
  
  #articles/archives.rhtml
  l.store "No articles found", "Niciun articol nu a fost găsit"
  
  #articles/comment_preview.rhtml
  l.store "is about to say", "vrea să scrie"
  
  #articles/groupings.rhtml
  l.store "There are", "Sînt"
  
  #articles/index.rhtml
  l.store "Read more", "Citește mai departe"
  l.store "Older posts", "Articole mai vechi"
  
  #articles/read.rhtml
  l.store "Leave a response", "Comentează"
  l.store "Use the following link to trackback from your own site", "Folosește link-ul următor pentru a realiza o retrolegătură de la site-ul tău"
  l.store "RSS feed for this post", "Flux RSS pentru acest articol"
  l.store "trackback uri", "URL pentru retrolegătură"
  l.store "Comments are disabled", "Comentariile sînt dezactivate"
 
  l.store "Pictures from", "Imagini de la"
  
  
  # The following were added by alxx (alxx@indigenious.ro)
  #vendor/plugins/xml_sidebar/views/content.rhtml
  l.store 'Syndicate', 'Sindicalizare'
  l.store 'Articles feed', 'RSS articole'
  l.store 'Comments feed', 'RSS comentarii'
  l.store 'Trackbacks feed', 'RSS retrolegături'
  l.store 'Articles', 'Articole'
  l.store 'Comments', 'Comentarii'
  l.store 'Trackbacks', 'Retrolegături'
  
  #vendor/plugins/category_sidebar/views/content.rhtml
  l.store 'Categories', 'Categorii'
  
  #app/helpers/articles_helper.rb
  l.store 'Posted in', 'Publicat în'
  l.store 'posted in', 'publicat în'
  
  #app/helpers/base_helper.rb
  l.store 'Back to overview', 'Înapoi'
  
  #views/shared/_search.rhtml
  l.store 'Live Search', 'Căutare'
  
  #articles/_comment_box.rhtml
  l.store 'submit', 'Trimite'
  
  #app/helpers/application_helper.rb
  l.store 'no', 'fără'
  l.store 'comment', 'comentariu'
  l.store 'comments', 'comentarii'
  l.store 'trackback', 'retrolegătură'
  l.store 'trackbacks', 'retrolegături'
  l.store 'less than', 'mai puțin de'
  l.store 'a minute', 'un minut'
  l.store 'second', 'secundă'
  l.store 'seconds', 'secunde'
  l.store 'minute', 'minut'
  l.store 'minutes', 'minute'
  l.store 'hour', 'oră'
  l.store 'hours', 'ore'
  l.store '20 seconds', '20 de secunde'
  l.store 'half a minute', 'jumătate de minut'
  l.store 'about', 'cam'
  l.store '1 hour', 'o oră'
  l.store '1 minute', 'un minut'  
  l.store '1 day', 'o zi'
  l.store '1 year', 'un an'
  l.store '1 month', 'o lună'
  l.store 'day', 'zi'
  l.store 'days', 'zile'
  l.store 'month', 'lună'
  l.store 'months', 'luni'
  l.store 'year', 'an'
  l.store 'years', 'ani'
  l.store 'over', 'peste'
  
  #views/articles/_comment_box.rhtml
  l.store 'leave', 'lasă'
  
  # All Javascript strings go here, with the js_ prefix (only needed in this file)
  l.store 'js_hour', 'оră'
  l.store 'js_minute', 'minut'
  l.store 'js_hours', 'ore'
  l.store 'js_minutes', 'minute'
  l.store 'js_days', 'zile'
  l.store 'js_in', 'peste'
  l.store 'js_since', 'acum'
  l.store 'js_from now', ' '
  l.store 'js_ago', ' '
  l.store 'js_on', 'în'
  l.store 'js_less than a minute', 'mai puțin de un minut'
  l.store 'js_about one hour', 'cam o oră'
  l.store 'js_one day', 'o zi'
  l.store 'js_about one day', 'cam o zi'
  
  
end
